@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -62,7 +62,7 @@ __all__ = ("BudgetsClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -82,7 +82,7 @@ class Exceptions:
 
 class BudgetsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html)
     """
 
@@ -98,7 +98,7 @@ class BudgetsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#can_paginate)
         """
 
@@ -107,12 +107,12 @@ class BudgetsClient(BaseClient):
         *,
         AccountId: str,
         Budget: "BudgetTypeDef",
-        NotificationsWithSubscribers: List["NotificationWithSubscribersTypeDef"] = None
+        NotificationsWithSubscribers: Sequence["NotificationWithSubscribersTypeDef"] = ...
     ) -> Dict[str, Any]:
         """
         Creates a budget and, if included, notifications and subscribers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.create_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.create_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#create_budget)
         """
 
@@ -127,12 +127,12 @@ class BudgetsClient(BaseClient):
         Definition: "DefinitionTypeDef",
         ExecutionRoleArn: str,
         ApprovalModel: ApprovalModelType,
-        Subscribers: List["SubscriberTypeDef"]
+        Subscribers: Sequence["SubscriberTypeDef"]
     ) -> CreateBudgetActionResponseTypeDef:
         """
         Creates a budget action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.create_budget_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.create_budget_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#create_budget_action)
         """
 
@@ -142,12 +142,12 @@ class BudgetsClient(BaseClient):
         AccountId: str,
         BudgetName: str,
         Notification: "NotificationTypeDef",
-        Subscribers: List["SubscriberTypeDef"]
+        Subscribers: Sequence["SubscriberTypeDef"]
     ) -> Dict[str, Any]:
         """
         Creates a notification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.create_notification)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.create_notification)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#create_notification)
         """
 
@@ -162,7 +162,7 @@ class BudgetsClient(BaseClient):
         """
         Creates a subscriber.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.create_subscriber)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.create_subscriber)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#create_subscriber)
         """
 
@@ -170,7 +170,7 @@ class BudgetsClient(BaseClient):
         """
         Deletes a budget.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.delete_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.delete_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#delete_budget)
         """
 
@@ -180,7 +180,7 @@ class BudgetsClient(BaseClient):
         """
         Deletes a budget action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.delete_budget_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.delete_budget_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#delete_budget_action)
         """
 
@@ -190,7 +190,7 @@ class BudgetsClient(BaseClient):
         """
         Deletes a notification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.delete_notification)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.delete_notification)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#delete_notification)
         """
 
@@ -205,7 +205,7 @@ class BudgetsClient(BaseClient):
         """
         Deletes a subscriber.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.delete_subscriber)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.delete_subscriber)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#delete_subscriber)
         """
 
@@ -213,7 +213,7 @@ class BudgetsClient(BaseClient):
         """
         Describes a budget.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.describe_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.describe_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget)
         """
 
@@ -223,7 +223,7 @@ class BudgetsClient(BaseClient):
         """
         Describes a budget action detail.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.describe_budget_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.describe_budget_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget_action)
         """
 
@@ -233,34 +233,34 @@ class BudgetsClient(BaseClient):
         AccountId: str,
         BudgetName: str,
         ActionId: str,
-        TimePeriod: "TimePeriodTypeDef" = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        TimePeriod: "TimePeriodTypeDef" = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> DescribeBudgetActionHistoriesResponseTypeDef:
         """
         Describes a budget action history detail.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.describe_budget_action_histories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.describe_budget_action_histories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget_action_histories)
         """
 
     def describe_budget_actions_for_account(
-        self, *, AccountId: str, MaxResults: int = None, NextToken: str = None
+        self, *, AccountId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeBudgetActionsForAccountResponseTypeDef:
         """
         Describes all of the budget actions for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.describe_budget_actions_for_account)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.describe_budget_actions_for_account)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget_actions_for_account)
         """
 
     def describe_budget_actions_for_budget(
-        self, *, AccountId: str, BudgetName: str, MaxResults: int = None, NextToken: str = None
+        self, *, AccountId: str, BudgetName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeBudgetActionsForBudgetResponseTypeDef:
         """
         Describes all of the budget actions for a budget.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.describe_budget_actions_for_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.describe_budget_actions_for_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget_actions_for_budget)
         """
 
@@ -269,34 +269,34 @@ class BudgetsClient(BaseClient):
         *,
         AccountId: str,
         BudgetName: str,
-        TimePeriod: "TimePeriodTypeDef" = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        TimePeriod: "TimePeriodTypeDef" = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> DescribeBudgetPerformanceHistoryResponseTypeDef:
         """
         Describes the history for `DAILY` , `MONTHLY` , and `QUARTERLY` budgets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.describe_budget_performance_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.describe_budget_performance_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget_performance_history)
         """
 
     def describe_budgets(
-        self, *, AccountId: str, MaxResults: int = None, NextToken: str = None
+        self, *, AccountId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeBudgetsResponseTypeDef:
         """
         Lists the budgets that are associated with an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.describe_budgets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.describe_budgets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budgets)
         """
 
     def describe_notifications_for_budget(
-        self, *, AccountId: str, BudgetName: str, MaxResults: int = None, NextToken: str = None
+        self, *, AccountId: str, BudgetName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeNotificationsForBudgetResponseTypeDef:
         """
         Lists the notifications that are associated with a budget.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.describe_notifications_for_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.describe_notifications_for_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_notifications_for_budget)
         """
 
@@ -306,13 +306,13 @@ class BudgetsClient(BaseClient):
         AccountId: str,
         BudgetName: str,
         Notification: "NotificationTypeDef",
-        MaxResults: int = None,
-        NextToken: str = None
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> DescribeSubscribersForNotificationResponseTypeDef:
         """
         Lists the subscribers that are associated with a notification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.describe_subscribers_for_notification)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.describe_subscribers_for_notification)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_subscribers_for_notification)
         """
 
@@ -322,21 +322,21 @@ class BudgetsClient(BaseClient):
         """
         Executes a budget action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.execute_budget_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.execute_budget_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#execute_budget_action)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#generate_presigned_url)
         """
 
@@ -344,7 +344,7 @@ class BudgetsClient(BaseClient):
         """
         Updates a budget.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.update_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.update_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#update_budget)
         """
 
@@ -354,17 +354,17 @@ class BudgetsClient(BaseClient):
         AccountId: str,
         BudgetName: str,
         ActionId: str,
-        NotificationType: NotificationTypeType = None,
-        ActionThreshold: "ActionThresholdTypeDef" = None,
-        Definition: "DefinitionTypeDef" = None,
-        ExecutionRoleArn: str = None,
-        ApprovalModel: ApprovalModelType = None,
-        Subscribers: List["SubscriberTypeDef"] = None
+        NotificationType: NotificationTypeType = ...,
+        ActionThreshold: "ActionThresholdTypeDef" = ...,
+        Definition: "DefinitionTypeDef" = ...,
+        ExecutionRoleArn: str = ...,
+        ApprovalModel: ApprovalModelType = ...,
+        Subscribers: Sequence["SubscriberTypeDef"] = ...
     ) -> UpdateBudgetActionResponseTypeDef:
         """
         Updates a budget action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.update_budget_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.update_budget_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#update_budget_action)
         """
 
@@ -379,7 +379,7 @@ class BudgetsClient(BaseClient):
         """
         Updates a notification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.update_notification)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.update_notification)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#update_notification)
         """
 
@@ -395,7 +395,7 @@ class BudgetsClient(BaseClient):
         """
         Updates a subscriber.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Client.update_subscriber)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Client.update_subscriber)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#update_subscriber)
         """
 
@@ -404,7 +404,7 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_budget_action_histories"]
     ) -> DescribeBudgetActionHistoriesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionHistories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionHistories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionhistoriespaginator)
         """
 
@@ -413,7 +413,7 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_budget_actions_for_account"]
     ) -> DescribeBudgetActionsForAccountPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForAccount)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForAccount)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionsforaccountpaginator)
         """
 
@@ -422,7 +422,7 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_budget_actions_for_budget"]
     ) -> DescribeBudgetActionsForBudgetPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForBudget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForBudget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionsforbudgetpaginator)
         """
 
@@ -431,7 +431,7 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_budget_performance_history"]
     ) -> DescribeBudgetPerformanceHistoryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetPerformanceHistory)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetPerformanceHistory)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetperformancehistorypaginator)
         """
 
@@ -440,7 +440,7 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_budgets"]
     ) -> DescribeBudgetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetspaginator)
         """
 
@@ -449,7 +449,7 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_notifications_for_budget"]
     ) -> DescribeNotificationsForBudgetPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describenotificationsforbudgetpaginator)
         """
 
@@ -458,6 +458,6 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_subscribers_for_notification"]
     ) -> DescribeSubscribersForNotificationPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describesubscribersfornotificationpaginator)
         """
