@@ -30,8 +30,9 @@ Usage::
     describe_subscribers_for_notification_paginator: DescribeSubscribersForNotificationPaginator = client.get_paginator("describe_subscribers_for_notification")
     ```
 """
-from typing import Iterator
+from typing import Generic, Iterator, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
@@ -58,9 +59,19 @@ __all__ = (
 )
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class DescribeBudgetActionHistoriesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionHistories)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionHistories)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionhistoriespaginator)
     """
 
@@ -70,48 +81,48 @@ class DescribeBudgetActionHistoriesPaginator(Boto3Paginator):
         AccountId: str,
         BudgetName: str,
         ActionId: str,
-        TimePeriod: "TimePeriodTypeDef" = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeBudgetActionHistoriesResponseTypeDef]:
+        TimePeriod: "TimePeriodTypeDef" = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeBudgetActionHistoriesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionHistories.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionHistories.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionhistoriespaginator)
         """
 
 
 class DescribeBudgetActionsForAccountPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForAccount)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForAccount)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionsforaccountpaginator)
     """
 
     def paginate(
-        self, *, AccountId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeBudgetActionsForAccountResponseTypeDef]:
+        self, *, AccountId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeBudgetActionsForAccountResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForAccount.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForAccount.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionsforaccountpaginator)
         """
 
 
 class DescribeBudgetActionsForBudgetPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForBudget)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForBudget)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionsforbudgetpaginator)
     """
 
     def paginate(
-        self, *, AccountId: str, BudgetName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeBudgetActionsForBudgetResponseTypeDef]:
+        self, *, AccountId: str, BudgetName: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeBudgetActionsForBudgetResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForBudget.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForBudget.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionsforbudgetpaginator)
         """
 
 
 class DescribeBudgetPerformanceHistoryPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetPerformanceHistory)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetPerformanceHistory)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetperformancehistorypaginator)
     """
 
@@ -120,48 +131,48 @@ class DescribeBudgetPerformanceHistoryPaginator(Boto3Paginator):
         *,
         AccountId: str,
         BudgetName: str,
-        TimePeriod: "TimePeriodTypeDef" = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeBudgetPerformanceHistoryResponseTypeDef]:
+        TimePeriod: "TimePeriodTypeDef" = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeBudgetPerformanceHistoryResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetPerformanceHistory.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetPerformanceHistory.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetperformancehistorypaginator)
         """
 
 
 class DescribeBudgetsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetspaginator)
     """
 
     def paginate(
-        self, *, AccountId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeBudgetsResponseTypeDef]:
+        self, *, AccountId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeBudgetsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetspaginator)
         """
 
 
 class DescribeNotificationsForBudgetPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describenotificationsforbudgetpaginator)
     """
 
     def paginate(
-        self, *, AccountId: str, BudgetName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeNotificationsForBudgetResponseTypeDef]:
+        self, *, AccountId: str, BudgetName: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeNotificationsForBudgetResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describenotificationsforbudgetpaginator)
         """
 
 
 class DescribeSubscribersForNotificationPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describesubscribersfornotificationpaginator)
     """
 
@@ -171,9 +182,9 @@ class DescribeSubscribersForNotificationPaginator(Boto3Paginator):
         AccountId: str,
         BudgetName: str,
         Notification: "NotificationTypeDef",
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeSubscribersForNotificationResponseTypeDef]:
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeSubscribersForNotificationResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.13/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describesubscribersfornotificationpaginator)
         """
