@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     ActionStatusType,
@@ -162,8 +162,8 @@ _OptionalBudgetTypeDef = TypedDict(
     "_OptionalBudgetTypeDef",
     {
         "BudgetLimit": "SpendTypeDef",
-        "PlannedBudgetLimits": Dict[str, "SpendTypeDef"],
-        "CostFilters": Dict[str, List[str]],
+        "PlannedBudgetLimits": Mapping[str, "SpendTypeDef"],
+        "CostFilters": Mapping[str, Sequence[str]],
         "CostTypes": "CostTypesTypeDef",
         "TimePeriod": "TimePeriodTypeDef",
         "CalculatedSpend": "CalculatedSpendTypeDef",
@@ -235,7 +235,7 @@ CreateBudgetActionRequestRequestTypeDef = TypedDict(
         "Definition": "DefinitionTypeDef",
         "ExecutionRoleArn": str,
         "ApprovalModel": ApprovalModelType,
-        "Subscribers": List["SubscriberTypeDef"],
+        "Subscribers": Sequence["SubscriberTypeDef"],
     },
 )
 
@@ -259,7 +259,7 @@ _RequiredCreateBudgetRequestRequestTypeDef = TypedDict(
 _OptionalCreateBudgetRequestRequestTypeDef = TypedDict(
     "_OptionalCreateBudgetRequestRequestTypeDef",
     {
-        "NotificationsWithSubscribers": List["NotificationWithSubscribersTypeDef"],
+        "NotificationsWithSubscribers": Sequence["NotificationWithSubscribersTypeDef"],
     },
     total=False,
 )
@@ -277,7 +277,7 @@ CreateNotificationRequestRequestTypeDef = TypedDict(
         "AccountId": str,
         "BudgetName": str,
         "Notification": "NotificationTypeDef",
-        "Subscribers": List["SubscriberTypeDef"],
+        "Subscribers": Sequence["SubscriberTypeDef"],
     },
 )
 
@@ -644,9 +644,9 @@ _RequiredIamActionDefinitionTypeDef = TypedDict(
 _OptionalIamActionDefinitionTypeDef = TypedDict(
     "_OptionalIamActionDefinitionTypeDef",
     {
-        "Roles": List[str],
-        "Groups": List[str],
-        "Users": List[str],
+        "Roles": Sequence[str],
+        "Groups": Sequence[str],
+        "Users": Sequence[str],
     },
     total=False,
 )
@@ -684,7 +684,7 @@ NotificationWithSubscribersTypeDef = TypedDict(
     "NotificationWithSubscribersTypeDef",
     {
         "Notification": "NotificationTypeDef",
-        "Subscribers": List["SubscriberTypeDef"],
+        "Subscribers": Sequence["SubscriberTypeDef"],
     },
 )
 
@@ -713,7 +713,7 @@ ScpActionDefinitionTypeDef = TypedDict(
     "ScpActionDefinitionTypeDef",
     {
         "PolicyId": str,
-        "TargetIds": List[str],
+        "TargetIds": Sequence[str],
     },
 )
 
@@ -730,7 +730,7 @@ SsmActionDefinitionTypeDef = TypedDict(
     {
         "ActionSubType": ActionSubTypeType,
         "Region": str,
-        "InstanceIds": List[str],
+        "InstanceIds": Sequence[str],
     },
 )
 
@@ -767,7 +767,7 @@ _OptionalUpdateBudgetActionRequestRequestTypeDef = TypedDict(
         "Definition": "DefinitionTypeDef",
         "ExecutionRoleArn": str,
         "ApprovalModel": ApprovalModelType,
-        "Subscribers": List["SubscriberTypeDef"],
+        "Subscribers": Sequence["SubscriberTypeDef"],
     },
     total=False,
 )
